==> web2ldap-1.0.29.tbz: share/web2ldap/pylib/w2lapp/schema/plugins/vpim.py <==
"""
web2ldap plugin classes for attributes defined in VPIM (see RFC 4237)

$Id: vpim.py,v 1.2 2009/03/30 00:13:27 michael Exp $
"""

import pyweblib.forms

from w2lapp.core import utf2display

from w2lapp.schema.syntaxes import LDAPSyntax,IA5String,SelectList,RFC822Address,syntax_registry


syntax_registry.registerAttrType(
  RFC822Address.oid,[
    '1.3.6.1.1.11.1.2.2', # vPIMRfc822Mailbox
  ]
)


class VPIMExtendedAbsenceStatus(SelectList):
  oid = 'VPIMExtendedAbsenceStatus-oid'
  desc = ''

  attr_value_dict = {
    '':'',
    'Off':'Off',
    'On':'On',
    'MsgBlocked':'MsgBlocked',
  }

syntax_registry.registerAttrType(
  VPIMExtendedAbsenceStatus.oid,[
    '1.3.6.1.1.11.1.2.7', # vPIMExtendedAbsenceStatus
  ]
)


class VPIMSupportedUABehaviors(SelectList):
  oid = 'VPIMSupportedUABehaviors-oid'
  desc = ''

  attr_value_dict = {
    '':'',
    'MessageDispositionNotification':'recipient will send a MDN in response to an MDN request',
    'MessageSensitivity':'recipient supports sensitivity indication',
    'MessageImportance':'recipient supports importance indication',
  }

syntax_registry.registerAttrType(
  VPIMSupportedUABehaviors.oid,[
    '1.3.6.1.1.11.1.2.8', # vPIMSupportedUABehaviors
  ]
)


class VPIMSupportedAudioMediaTypes(SelectList):
  oid = 'VPIMSupportedAudioMediaTypes-oid'
  desc = 'Audio Media Types'

  attr_value_dict = {
    'audio/basic':'audio/basic',
    'audio/mpeg':'audio/mpeg',
    'audio/x-aiff':'audio/x-aiff',
    'audio/x-realaudio':'audio/x-realaudio',
    'audio/x-wav':'audio/x-wav',
  }

syntax_registry.registerAttrType(
  VPIMSupportedAudioMediaTypes.oid,[
    '1.3.6.1.1.11.1.2.5', # vPIMSupportedAudioMediaTypes 
  ]
)


# Register all syntax classes in this module
for name in dir():
  syntax_registry.registerSyntaxClass(eval(name))

==> web2ldap-1.1.23.tbz: share/web2ldap/pylib/w2lapp/schema/plugins/vpim.py <==
# -*- coding: utf-8 -*-
"""
web2ldap plugin classes for attributes defined in VPIM (see RFC 4237)

$Id: vpim.py,v 1.5 2012/05/02 18:27:29 michael Exp $
"""

from w2lapp.schema.syntaxes import LDAPSyntax,IA5String,SelectList,RFC822Address,syntax_registry


syntax_registry.registerAttrType(
  RFC822Address.oid,[
    '1.3.6.1.1.11.1.2.2', # vPIMRfc822Mailbox
  ]
)


class VPIMExtendedAbsenceStatus(SelectList):
  oid = 'VPIMExtendedAbsenceStatus-oid'
  desc = ''

  attr_value_dict = {
    u'':u'',
    u'Off':u'Off',
    u'On':u'On',
    u'MsgBlocked':u'MsgBlocked',
  }

syntax_registry.registerAttrType(
  VPIMExtendedAbsenceStatus.oid,[
    '1.3.6.1.1.11.1.2.7', # vPIMExtendedAbsenceStatus
  ]
)


class VPIMSupportedUABehaviors(SelectList):
  oid = 'VPIMSupportedUABehaviors-oid'
  desc = ''

  attr_value_dict = {
    u'':'',
    u'MessageDispositionNotification':u'recipient will send a MDN in response to an MDN request',
    u'MessageSensitivity':u'recipient supports sensitivity indication',
    u'MessageImportance':u'recipient supports importance indication',
  }

syntax_registry.registerAttrType(
  VPIMSupportedUABehaviors.oid,[
    '1.3.6.1.1.11.1.2.8', # vPIMSupportedUABehaviors
  ]
)


class VPIMSupportedAudioMediaTypes(SelectList):
  oid = 'VPIMSupportedAudioMediaTypes-oid'
  desc = 'Audio Media Types'

  attr_value_dict = {
    u'audio/basic':u'audio/basic',
    u'audio/mpeg':u'audio/mpeg',
    u'audio/x-aiff':u'audio/x-aiff',
    u'audio/x-realaudio':u'audio/x-realaudio',
    u'audio/x-wav':u'audio/x-wav',
  }

syntax_registry.registerAttrType(
  VPIMSupportedAudioMediaTypes.oid,[
    '1.3.6.1.1.11.1.2.5', # vPIMSupportedAudioMediaTypes 
  ]
)


# Register all syntax classes in this module
for name in dir():
  syntax_registry.registerSyntaxClass(eval(name))
